@@ -52,11 +52,15 @@ sub get_out_cookie    {$_[0]->out_cookies->get_header($_[1])}
 sub method {
 	my $xm = $_[0]{method};
 	return $xm if $xm;
-	if (my $hmo = $_[0]->{env}{X_HTTP_METHOD_OVERRIDE}) {
+	if (my $hmo = $_[0]->{env}{HTTP_X_HTTP_METHOD_OVERRIDE}) {
 		$_[0]{method} = uc $hmo;
-	} elsif ($_[0]->{env}{UPGRADE} eq 'WebSocket' && $_[0]->{env}{CONNECTION} eq 'Upgrade') {
+	} elsif ($_[0]->{env}{HTTP_UPGRADE}
+		&& $_[0]->{env}{HTTP_CONNECTION}
+		&& $_[0]->{env}{HTTP_UPGRADE} eq 'WebSocket'
+		&& $_[0]->{env}{HTTP_CONNECTION} eq 'Upgrade')
+	{
 		$_[0]{method} = 'WEBSOCKET';
-	} elsif ($_[0]->{env}{ACCEPT} eq 'text/event-stream') {
+	} elsif ($_[0]->{env}{HTTP_ACCEPT} eq 'text/event-stream') {
 		$_[0]{method} = 'SSE';
 	} else {
 		$_[0]{method} = $_[0]->{env}{REQUEST_METHOD};
@@ -255,7 +259,10 @@ sub _parse_request_body {
 	my $read_body_sub = sub {
 		$self->{raw_body} = '';
 		my $buffer;
-		while ($cl && (!$coro_ae || Coro::AnyEvent::readable $self->_input) && $self->_input->read($buffer, $cl)) {
+		while ($cl
+			&& (!$coro_ae || $Coro::main == $Coro::current || Coro::AnyEvent::readable $self->_input)
+			&& $self->_input->read($buffer, $cl))
+		{
 			$self->{raw_body} .= $buffer;
 			$cl -= length $buffer;
 		}
@@ -306,7 +313,7 @@ sub _parse_multipart_form {
 		$start = index($buffer, $end_boundary) if $start == -1;
 		$buffer .= $chunk
 			if $start == -1
-			&& (!$coro_ae || Coro::AnyEvent::readable $self->_input)
+			&& (!$coro_ae || $Coro::main == $Coro::current || Coro::AnyEvent::readable $self->_input)
 			&& $input->read($chunk, _read_chunk_size);
 		last if $buffer eq '';
 		$start = index($buffer, $start_boundary) if $start == -1;
